
project, uses("do_newspapers_benefit_incumbents.dta")

	*Figure 2
	use do_newspapers_benefit_incumbents.dta, clear
	gen bin = rv - mod(rv,1) +100		
	gen landowner = regexm(occupation, "Landowner")
	gen sen_name = regexm(candidate, "sen,")

	binscatter win_prev rv if abs(rv)<15    , rd(0) xq(bin) ylabel(-0 (.1) .8) xlabel(-15 (5) 15) ytitle("Victory, t-1") title("Previous Victory") xtitle("Vote Share Margin, t") saving("./figures_tables/win_prev.gph", replace) line(qfit)
	binscatter landowner rv if abs(rv)<15   , rd(0) xq(bin) ylabel(-0 (.1) .8) xlabel(-15 (5) 15) ytitle("Landowner, t") title("Land Ownership") xtitle("Vote Share Margin, t") saving("./figures_tables/landowner.gph", replace) line(qfit)
	binscatter newspapers_aligned rv if abs(rv)<15   , rd(0) xq(bin) ylabel(-0 (.1) .8) xlabel(-15 (5) 15) ytitle("Partisan-Aligned Newspapers, t") title("Newspapers") xtitle("Vote Share Margin, t") saving("./figures_tables/newspapers_aligned.gph", replace) line(qfit)
	binscatter sen_name rv if abs(rv)<15   , rd(0) xq(bin) ylabel(-0 (.1) .8) xlabel(-15 (5) 15) ytitle("Patronymic Surname, t") title("Working-Class Surname") xtitle("Vote Share Margin, t") saving("./figures_tables/sen_name.gph", replace) line(qfit)

	graph combine  "./figures_tables/win_prev"  "./figures_tables/landowner"  "./figures_tables/newspapers_aligned"   "./figures_tables/sen_name" , xsize(20) ysize(20) xcommon // iscale(1.3)
	graph export "./figures_tables/balance_rd.eps", replace
	
project, creates("./figures_tables/balance_rd.eps") 



	*Additional balance tests in the Appendix
	
	*Table A.4: Pre-treatment Balance on Winning Office at time t-1.	
	use do_newspapers_benefit_incumbents.dta, clear
	estimates clear
	rename win  RD_Estimate
	label var RD_Estimate "\(victory_{ict}\)"	
	
	eststo: rdrobust win_prev rv, c(0) vce(cluster constituency_id)
	estadd scalar obs = e(N_h_r) + e(N_h_l)
	estadd scalar bw = e(h_r)
	
	eststo: reg win_prev RD_Estimate rv rvXwin  if abs(rv)<10 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =10
	
	eststo: reg win_prev RD_Estimate rv rvXwin  if abs(rv)<15 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =15
	
	eststo: reg win_prev RD_Estimate rv rvXwin rv_2 winXrv_2 if abs(rv)<20 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =20
		
		
	esttab using "./figures_tables/balance_win_prev.tex",  replace keep(RD_Estimate  ) label se  ///
	substitute(bw Bandwidth obs N "\hline" "\midrule" ) compress  noobs nomtitles nonum fragment scalar(obs bw) b( %4.3f)  sfmt(%9.0fc  )  nostar
	
project, creates("./figures_tables/balance_win_prev.tex") 
	
	
	

	*Table A.5: Pre-treatment Balance on Press Coverage at time t.
	use do_newspapers_benefit_incumbents.dta, clear
	estimates clear
	rename win  RD_Estimate
	label var RD_Estimate "\(victory_{ict}\)"	
	
	eststo: rdrobust log_hits_campaign_prev rv, c(0) vce(cluster constituency_id)
	estadd scalar obs = e(N_h_r) + e(N_h_l)
	estadd scalar bw = e(h_r)
	
	eststo: reg log_hits_campaign_prev RD_Estimate rv rvXwin  if abs(rv)<10 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =10
	
	eststo: reg log_hits_campaign_prev RD_Estimate rv rvXwin  if abs(rv)<15 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =15
	
	eststo: reg log_hits_campaign_prev RD_Estimate rv rvXwin rv_2 winXrv_2 if abs(rv)<20 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =20
		
		
	esttab using "./figures_tables/balance_log_hits_campaign_prev.tex",  replace keep(RD_Estimate  ) label se  ///
	substitute(bw Bandwidth obs N "\hline" "\midrule" ) compress  noobs nomtitles nonum fragment scalar(obs bw) b( %4.3f)  sfmt(%9.0fc  )  nostar
				
	
project, creates("./figures_tables/balance_log_hits_campaign_prev.tex") 


		
	*Table A.6: Pre-treatment Balance on Candidate-Aligned Newspapers at time t.
	
	use do_newspapers_benefit_incumbents.dta, clear
	estimates clear
	rename win  RD_Estimate
	label var RD_Estimate "\(victory_{ict}\)"	
	
	eststo: rdrobust newspapers_aligned rv, c(0) vce(cluster constituency_id)
	estadd scalar obs = e(N_h_r) + e(N_h_l)
	estadd scalar bw = e(h_r)
	
	eststo: reg newspapers_aligned RD_Estimate rv rvXwin  if abs(rv)<10 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =10
	
	eststo: reg newspapers_aligned RD_Estimate rv rvXwin  if abs(rv)<15 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =15
	
	eststo: reg newspapers_aligned RD_Estimate rv rvXwin rv_2 winXrv_2 if abs(rv)<20 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =20
		
		
	esttab using "./figures_tables/balance_newspapers_aligned.tex",  replace keep(RD_Estimate  ) label se  ///
	substitute(bw Bandwidth obs N "\hline" "\midrule" ) compress  noobs nomtitles nonum fragment scalar(obs bw) b( %4.3f)  sfmt(%9.0fc  )  nostar
		
		
project, creates("./figures_tables/balance_newspapers_aligned.tex") 
		
		
		
		
	*Table A.11: Difference-in-Differences Design: Electoral Competitiveness and Newspaper Entry.
	use do_newspapers_benefit_incumbents.dta, clear
	estimates clear
	drop if newspapers==.
	keep if win==1
	replace vtshmargin = vtshmargin/100
	label var vtshmargin "\(vote\,\, share\,\,margin_{ct}\)"
	
	eststo: reghdfe  newspapers  vtshmargin, absorb(constituency_id date) cluster(constituency_id) 
	
	eststo: reghdfe  newspapers vtshmargin electors , absorb(constituency_id date) cluster(constituency_id) 

	eststo: reghdfe  newspapers vtshmargin electors urban_pct, absorb(constituency_id date) cluster(constituency_id) 
	
	eststo: reghdfe  newspapers vtshmargin electors urban_pct railroad , absorb(constituency_id date) cluster(constituency_id) 
	
	eststo: reghdfe  newspapers vtshmargin electors urban_pct railroad , absorb(constituency_id date constituency_id#c.date) cluster(constituency_id) 
	
	esttab using "./figures_tables/did_newspapers_vtshmargin.tex",  replace keep(vtshmargin  ) label se  ///
	substitute( "\hline" "\midrule" ) compress  noobs nomtitles  fragment scalar(N ) b( %4.3f)  sfmt(%9.0fc ) nostar  
	
			
project, creates("./figures_tables/did_newspapers_vtshmargin.tex") 
	
	
		
	*Figure A.2: Predictors of Newspaper Entry: # Electors.
	use do_newspapers_benefit_incumbents.dta, clear
	keep if win==1
	egen time = group(date)
	binscatter newspapers electors,  n(10) ylabel(0 (.5) 3)  ylabel(0 (.5) 3) title("Cross-section") ///
	xtitle("electors" )  saving("./figures_tables/predictors_of_entry_electors.gph", replace) 
	binscatter newspapers electors, absorb(constituency_id) controls(i.time) title("Constituency- and Time-Fixed Effects") n(10) ylabel(0 (.5) 3) ///
	xtitle("electors" )  saving("./figures_tables/predictors_of_entry_electors_FE.gph", replace) 
	graph combine  "./figures_tables/predictors_of_entry_electors"  "./figures_tables/predictors_of_entry_electors_FE" , xsize(20) ysize(10)   iscale(1.3) ycommon
	graph export "./figures_tables/predictors_of_entry_electors.eps", replace
	
	*Figure A.3: Predictors of Newspaper Entry: % Electors Living in Urban Areas.	
	binscatter newspapers urban_pct,  n(10) ylabel(0 (.5) 3)  ylabel(0 (.5) 3) title("Cross-section") ///
	xtitle("% urban electors" )  saving("./figures_tables/predictors_of_entry_urban.gph", replace) 
	binscatter newspapers urban_pct, absorb(constituency_id) controls(i.time) title("Constituency- and Time-Fixed Effects") n(10) ylabel(0 (.5) 3) ///
	xtitle("% urban electors" )  saving("./figures_tables/predictors_of_entry_urban_FE.gph", replace) 
	graph combine  "./figures_tables/predictors_of_entry_urban"  "./figures_tables/predictors_of_entry_urban_FE" , xsize(20) ysize(10)   iscale(1.3) ycommon
	graph export "./figures_tables/predictors_of_entry_urban.eps", replace
	



	*Figure A.4: Predictors of Newspaper Entry: Constituency Connected to Railroad Network.
	binscatter newspapers railroad,  n(10) ylabel(0 (.5) 3)  ylabel(0 (.5) 3) title("Cross-section") ///
	xtitle("railroad" )  saving("./figures_tables/predictors_of_entry_railroad.gph", replace) 
	binscatter newspapers railroad, absorb(constituency_id) controls(i.time) title("Constituency- and Time-Fixed Effects") n(10) ylabel(0 (.5) 3) ///
	xtitle("railroad" )  saving("./figures_tables/predictors_of_entry_railroad_FE.gph", replace) 
	graph combine  "./figures_tables/predictors_of_entry_railroad"  "./figures_tables/predictors_of_entry_railroad_FE" , xsize(20) ysize(10)   iscale(1.3) ycommon
	graph export "./figures_tables/predictors_of_entry_railroad.eps", replace

	
	*Figure A.5: Predictors of Newspaper Entry: Vote Share Margin of Victory.
	binscatter newspapers vtshmargin,  n(10) ylabel(0 (.5) 3)  ylabel(0 (.5) 3) title("Cross-section") ///
	xtitle("vote share margin of victory" )  saving("./figures_tables/predictors_of_entry_vtshmargin.gph", replace) 
	binscatter newspapers vtshmargin, absorb(constituency_id) controls(i.time) title("Constituency- and Time-Fixed Effects") n(10) ylabel(0 (.5) 3) ///
	xtitle("vote share margin of victory" )  saving("./figures_tables/predictors_of_entry_vtshmargin_FE.gph", replace) 
	graph combine  "./figures_tables/predictors_of_entry_vtshmargin"  "./figures_tables/predictors_of_entry_vtshmargin_FE" , xsize(20) ysize(10)   iscale(1.3) ycommon
	graph export "./figures_tables/predictors_of_entry_vtshmargin.eps", replace

project, creates("./figures_tables/predictors_of_entry_vtshmargin.eps") 
project, creates("./figures_tables/predictors_of_entry_railroad.eps") 
project, creates("./figures_tables/predictors_of_entry_electors.eps") 
project, creates("./figures_tables/predictors_of_entry_urban.eps") 		
			
		
		
