

project, uses("do_newspapers_benefit_incumbents.dta")




	*Figure 3: Difference-in-Differences Design: Winning a Parliamentary Seat Leads to an Increase in the Press Coverage of Candidates' Electoral Campaigns.
	use do_newspapers_benefit_incumbents.dta, clear
	egen cand_id = group(candidate)
	sort cand_id date
	bys cand_id: gen win1 = win[_n+1]
	bys cand_id: gen win2 = win[_n+2]
	bys cand_id: gen win3 = win[_n+3]
	bys cand_id: gen win4 = win[_n+4]	
	
	egen Election = group(date)
	binscatter log_hits_campaign_next win , absorb(cand_id ) controls(i.Election ) noaddmean n(12) xtitle("Victory, t" "(Residualized)") ytitle("log candidate mentions, t+1" "(Residualized)") ylabel(-.4 (.1) .4) xlabel(-.6 (.2) .6) line(lfit) saving("./figures_tables/partial_regression_news.gph", replace)  

	rename win win0
	reghdfe log_hits_campaign_next   win4 win3 win2 win1 win0       , a(cand_id  Election ) cluster(cand_id)
	
	gen t = . 
	gen est = .
	gen upper90 = .
	gen upper95 = .
	gen lower90 = .
	gen lower95 = .	
	local t =0
	forval i = 0/4 {
		replace t =  -`t' if _n==`t' +1	
		replace est = _b[win`i'] if _n==`t' +1
		replace upper95 = _b[win`i'] + 1.96*_se[win`i'] if _n==`t'+1
		replace lower95 = _b[win`i'] - 1.96*_se[win`i'] if _n==`t'+1
		replace upper90 = _b[win`i'] + 1.64*_se[win`i'] if _n==`t'+1
		replace lower90 = _b[win`i'] - 1.64*_se[win`i'] if _n==`t'+1
		local t = `t'+1		
	}
	
	keep if t!=.
	keep est upper* lower* t	

	twoway  (rspike upper95 lower95 t,   lwidth(vthin)   	lcolor(black) ) || ///
			(rspike upper90 lower90 t,  lwidth(medthick) 	lcolor(black) ) || ///
			(dot est t , ndots(1) msymbol(s) mfcolor(white) mcolor(black) ) || ///
			, yline(0 , lpattern(solid) lcolor(black)) ytitle("Effect of Winning Office on" "log candidate mentions, t+1") ///
			legend( off ) ///
			xtitle("Elections Relative to Winning Office" " " )  saving("./figures_tables/did_news.gph", replace) ylabel(-.4 (.2) 1)
	graph combine  "./figures_tables/partial_regression_news"  "./figures_tables/did_news" , xsize(20) ysize(10)   iscale(1.25)
	graph export ./figures_tables/did_news.eps, replace	

project, creates("./figures_tables/did_news.eps") 
		






	*Figure 4: Regression-Discontinuity Design: Marginal Winners Receive More Local Press Coverage than Marginal Losers in the Subsequent Election.
	use do_newspapers_benefit_incumbents.dta, clear	
	gen bin = rv - mod(rv,1) +100	
	replace log_hits_campaign_prev = . if newspapers==.
	replace log_hits_campaign_next = . if newspapers==.
	replace log_hits = . if newspapers==. 
	binscatter log_hits_campaign_prev rv if abs(rv)<15  , rd(0) xq(bin) xlabel(-15 (5) 15)  title(  "Press Coverage" "Electoral Campaign t") xtitle("Vote Share Margin, t") saving("./figures_tables/rd_hits_campaign_prev.gph", replace) line(qfit) ytitle("log candidate mentions, t" ) //  ytitle("Log of Newspaper Mentions" "30 Days Before Election t" )
	binscatter log_hits_campaign_next rv if abs(rv)<15  , rd(0) xq(bin) xlabel(-15 (5) 15)  title(  "Press Coverage" "Electoral Campaign t+1") xtitle("Vote Share Margin, t") saving("./figures_tables/rd_hits_campaign_next.gph", replace) line(qfit) ytitle("log candidate mentions, t+1" ) //ytitle("Log of Newspaper Mentions" "30 Days Before Election t+1" )
	
	graph combine   "./figures_tables/rd_hits_campaign_prev"   "./figures_tables/rd_hits_campaign_next"  , xsize(20) ysize(10)  cols(3) ycommon  iscale(1.45)   
	graph export "./figures_tables/rd_newspaper_mentions.eps", replace

project, creates("./figures_tables/rd_newspaper_mentions.eps") 

				

		
		
		
	**Table 1: Table 1: Difference-in-Differences Design: Effect of Winning a Parliamentary Seat on Local News Coverage in the Subsequent Election.
	use do_newspapers_benefit_incumbents.dta, clear
	egen cand_id = group(candidate)
	egen party_date = group(party date) , missing
	estimates clear
	label var win "\(victory_{ict}\)"

	eststo: reghdfe log_hits_campaign_next   win      , a(cand_id  date ) cluster(cand_id)

	
	eststo: reghdfe log_hits_campaign_next   win newspapers electors urban_pct railroad vtsh , a(cand_id  date ) cluster(cand_id)
	
	
	eststo: reghdfe log_hits_campaign_next   win  newspapers electors urban_pct railroad vtsh , a(cand_id  party_date ) cluster(cand_id)
		
	
	eststo: reghdfe log_hits_campaign_next   win newspapers electors urban_pct railroad vtsh  , a(cand_id  party_date cand_id#c.date ) cluster(cand_id)
	
	esttab using "./figures_tables/did_log_hits_campaign_next.tex",  replace keep(win  ) label se  ///
	substitute(  "\hline" "\midrule" ) compress  noobs nomtitles  fragment scalar(N ) b( %4.3f)  sfmt(%9.0fc  ) nostar	
	
project, creates("./figures_tables/did_log_hits_campaign_next.tex") 

	
	
	*Table 2: Regression-Discontinuity Design: Effect of Winning Office on Local News Coverage in Subsequent Elections.
	use do_newspapers_benefit_incumbents.dta, clear
	egen cand_id = group(candidate)
	egen party_date = group(party date) , missing
	gen victories_prev = 0
	sort candidate date
	by candidate: replace victories_prev = win_prev + victories_prev[_n-1] if win_prev!=. & victories_prev[_n-1]!=.
	by candidate: gen campaigns_prev = _n
	estimates clear
	rename win  RD_Estimate
	label var RD_Estimate "\(victory_{ict}\)"	
	
	eststo: rdrobust log_hits_campaign_next rv, c(0) vce(cluster constituency_id)
	estadd scalar obs = e(N_h_r) + e(N_h_l)
	estadd scalar bw = e(h_r)
	
	eststo: reg log_hits_campaign_next RD_Estimate rv rvXwin  if abs(rv)<10 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =10
	
	eststo: reg log_hits_campaign_next RD_Estimate rv rvXwin  if abs(rv)<15 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =15
	
	eststo: reg log_hits_campaign_next RD_Estimate rv rvXwin rv_2 winXrv_2 if abs(rv)<20 , cluster(constituency_id)
	estadd scalar obs = e(N) 
	estadd scalar bw =20
		
		
	esttab using "./figures_tables/rdd_log_hits_campaign_next.tex",  replace keep(RD_Estimate  ) label se  ///
	substitute(bw Bandwidth obs N "\hline" "\midrule" ) compress  noobs nomtitles fragment scalar(obs bw) b( %4.3f)  sfmt(%9.0fc  )  nostar
	
project, creates("./figures_tables/rdd_log_hits_campaign_next.tex") 

	

		
	
	
	
	
	
	*Table A.2: Difference-in-Differences Design: Effect of Winning a Parliamentary Seat on Local News Coverage in the Subsequent Election.
	**DiD Tables: Effect of incumbency on news coverage in next election + interaction with newspapers_aligned
	use do_newspapers_benefit_incumbents.dta, clear
	egen cand_id = group(candidate)
	egen party_date = group(party date) , missing
	gen victories_prev = 0
	sort candidate date
	by candidate: replace victories_prev = win_prev + victories_prev[_n-1] if win_prev!=. & victories_prev[_n-1]!=.
	by candidate: gen campaigns_prev = _n
	estimates clear
	label var win "\(victory_{ict}\)"
	label var winXnewspapers_aligned "\(victory_{ict} \times aligned\,\,newspapers_{ict}\)"
	sort cand_id date
	duplicates tag cand_id date, gen(dup)
	drop if dup>0
	xtset cand_id date
	egen Date = group(date)	
	
	eststo: xtreg log_hits_campaign_next   win winXnewspapers_aligned   i.Date   , fe cluster(cand_id)
	
	
	eststo: xtreg log_hits_campaign_next   win winXnewspapers_aligned victories_prev  campaigns_prev i.Date , fe cluster(cand_id)
	
	
	eststo: xtreg log_hits_campaign_next   win winXnewspapers_aligned victories_prev  campaigns_prev i.party_date , fe cluster(cand_id)
		
	
	eststo: xtreg log_hits_campaign_next   win winXnewspapers_aligned victories_prev  campaigns_prev  i.party_date   i.cand_id#c.date, fe cluster(cand_id)
	
	esttab using "./figures_tables/did_log_hits_campaign_next_interaction_with_newspapers.tex",  replace keep(win winXnewspapers_aligned ) label se  ///
	substitute(  "\hline" "\midrule" ) compress  noobs nomtitles  fragment scalar(N ) b( %4.3f)  sfmt(%9.0fc  ) nostar	
							
project, creates("./figures_tables/did_log_hits_campaign_next_interaction_with_newspapers.tex") 
	
		
	

	
	
	
	*Table A.3: Difference-in-Differences Design: Effect of Winning a Parliamentary Seat on Local News Coverage in the Subsequent Election.
	*Effect of incumbency on news coverage (hits / [hits_politik + hits_rigsdag] )
	use do_newspapers_benefit_incumbents.dta, clear
	egen cand_id = group(candidate)
	duplicates tag cand_id date, gen(dup)
	drop if dup>0
	xtset cand_id date
	egen party_date = group(party date) , missing
	gen victories_prev = 0
	sort candidate date
	by candidate: replace victories_prev = win_prev + victories_prev[_n-1] if win_prev!=. & victories_prev[_n-1]!=.
	by candidate: gen campaigns_prev = _n
	estimates clear
	label var win "\(victory_{ict}\)"
	egen Date = group(date)

	eststo: xtreg  newscoverage   win    i.Date  , fe cluster(cand_id)

	
	eststo: xtreg  newscoverage   win   victories_prev  campaigns_prev i.Date  , fe cluster(cand_id)
	
	
	eststo: xtreg  newscoverage   win   victories_prev  campaigns_prev i.party_date  , fe cluster(cand_id)
		
	
	eststo: xtreg  newscoverage   win   victories_prev  campaigns_prev i.party_date   i.cand_id#c.date , fe  cluster(cand_id)
	
	
	esttab using "./figures_tables/did_newscoverage.tex",  replace keep(win  ) label se  ///
	substitute(  "\hline" "\midrule" ) compress  noobs nomtitles  fragment scalar(N ) b( %4.3f)  sfmt(%9.0fc  ) nostar	
	
	
							
project, creates("./figures_tables/did_newscoverage.tex") 
	
	
	
	
	
	
