
*partisan
project, uses("do_newspapers_benefit_incumbents.dta")

	*Figure 8: Difference-in-Differences Design: Effect of Incumbent-Aligned Newspapers on Reelection Rates.
	use do_newspapers_benefit_incumbents.dta, clear
	set matsize 1000
	keep if win==1
	sort constituency date
	gen win_højre=  party=="Højre"
	gen win_venstre=  party=="Venstre"
	gen win_radikale=  party=="Radikale"
	gen win_moderate=  party=="Moderate"
	gen win_socialdem=  party=="Socialdemokratiet"

	bys constituency: gen win_next_højre=  party[_n+1]=="Højre"
	bys constituency: gen win_next_venstre=  party[_n+1]=="Venstre"
	bys constituency: gen win_next_radikale=  party[_n+1]=="Radikale"
	bys constituency: gen win_next_socialdem=  party[_n+1]=="Socialdemokratiet"
	bys constituency: gen win_next_moderate=  party[_n+1]=="Moderate"
	drop if newspapers==.		
	drop if electiontype=="special"
	
	keep *_højre *_venstre *_radikale *_moderate *_socialdem constituency_id date   

	reshape long win_ win_next_ newspapertitles_ newspapers_ , i(constituency_id date) j(party) string
	egen party_constituency = group(constituency party)
	egen party_date = group(date party)
	egen constituency_date = group(constituency date)
	gen reelection = win_==1 & win_next_==1
	
	sort constituency_id party date
	order constituency_id party date reelection win_ win_next
	

	binscatter reelection newspapers_ , absorb(party_constituency ) controls(i.party_date ) noaddmean n(10) xlabel(-0.5 (.25) .5) ylabel(-0.05 (.025) .05) xtitle("Incumbent-Aligned Newspapers" "(Residualized)") ytitle("Reelection Rate" "(Residualized)")  line(lfit) saving("./figures_tables/partisan_partial_regression.gph", replace)  


	sort party_constituency date
	bys party_constituency: gen newspapers1 = newspapers_[_n+1]
	bys party_constituency: gen newspapers2 = newspapers_[_n+2]
	bys party_constituency: gen newspapers3 = newspapers_[_n+3]
	bys party_constituency: gen newspapers4 = newspapers_[_n+4]

	rename newspapers_ newspapers0
	
	reghdfe reelection newspapers*, absorb(party_constituency   party_date) cluster(constituency_id) 
	
	gen t = . 
	gen est = .
	gen upper90 = .
	gen upper95 = .
	gen lower90 = .
	gen lower95 = .	
	local t =0
	forval i = 0/4 {
		replace t =  -`t' if _n==`t' +1	
		replace est = _b[newspapers`i'] if _n==`t' +1
		replace upper95 = _b[newspapers`i'] + 1.96*_se[newspapers`i'] if _n==`t'+1
		replace lower95 = _b[newspapers`i'] - 1.96*_se[newspapers`i'] if _n==`t'+1
		replace upper90 = _b[newspapers`i'] + 1.64*_se[newspapers`i'] if _n==`t'+1
		replace lower90 = _b[newspapers`i'] - 1.64*_se[newspapers`i'] if _n==`t'+1
		local t = `t'+1		
	}
	
	keep if t!=.
	keep est upper* lower* t	

	twoway  (rspike upper95 lower95 t,   lwidth(vthin)   	lcolor(black) ) || ///
		(rspike upper90 lower90 t,  lwidth(medthick) 	lcolor(black) ) || ///
		(dot est t , ndots(1) msymbol(s) mfcolor(white) mcolor(black) ) || ///
		, yline(0 , lpattern(solid) lcolor(black))  legend( off )  ylabel(-.1 (.05) .15) ///
		ytitle("Effect of Incumbent-Aligned" "Newspaper on Reelection Rate") xtitle("Elections Relative to Entry of" "Incumbent-Aligned Newspaper" )	saving("./figures_tables/partisan_did_est.gph", replace)


	graph combine  "./figures_tables/partisan_partial_regression"  "./figures_tables/partisan_did_est" , xsize(20) ysize(10)   iscale(1.2)
	graph export ./figures_tables/partisan_did.eps, replace	
	
project, creates("./figures_tables/partisan_did.eps") 
	




	
	*Table 5: Difference-in-Differences Design: Effect of Incumbent-Aligned Newspapers on Reelection Rates.
	use do_newspapers_benefit_incumbents.dta, clear
	*keep if year>=1866
	estimates clear		
	set matsize 1000
	keep if win==1
	sort constituency date
	gen win_højre=  party=="Højre"
	gen win_venstre=  party=="Venstre"
	gen win_radikale=  party=="Radikale"
	gen win_moderate=  party=="Moderate"
	gen win_socialdem=  party=="Socialdemokratiet"

	bys constituency: gen win_next_højre=  party[_n+1]=="Højre"
	bys constituency: gen win_next_venstre=  party[_n+1]=="Venstre"
	bys constituency: gen win_next_radikale=  party[_n+1]=="Radikale"
	bys constituency: gen win_next_socialdem=  party[_n+1]=="Socialdemokratiet"
	bys constituency: gen win_next_moderate=  party[_n+1]=="Moderate"
	drop if newspapers==.		
	
	keep *_højre *_venstre *_radikale *_moderate *_socialdem constituency_id date electors urban_pct railroad vtshmargin   

	reshape long win_ win_next_ newspapertitles_ newspapers_, i(constituency_id date) j(party) string
	egen party_constituency = group(constituency party)
	egen party_date = group(date party)
	gen reelection = win_==1 & win_next_==1
	label var newspapers_ "\(aligned \,\,newspapers_{pct}\)"
	
	eststo: reghdfe reelection newspapers_ , absorb(party_constituency party_date) cluster(constituency_id) 

	
	eststo: reghdfe reelection newspapers_  electors , absorb(party_constituency party_date) cluster(constituency_id) 

	
	eststo: reghdfe reelection newspapers_ electors urban_pct, absorb(party_constituency party_date) cluster(constituency_id) 

	
	eststo: reghdfe reelection newspapers_ electors urban_pct railroad , absorb(party_constituency party_date) cluster(constituency_id) 

	
	eststo: reghdfe reelection newspapers_ electors urban_pct railroad vtshmargin, absorb(party_constituency party_date) cluster(constituency_id) 		

	
	eststo: reghdfe reelection newspapers_ electors urban_pct railroad vtshmargin, absorb(party_constituency party_date party_constituency#c.date) cluster(constituency_id) 

	
	esttab using "./figures_tables/partisan_did.tex",  replace keep(newspapers_  ) label se  ///
	substitute( "\hline" "\midrule" ) compress  noobs nomtitles  fragment scalar(N ) b( %4.3f)  sfmt(%9.0fc  ) nostar
		
project, creates("./figures_tables/partisan_did.tex") 

		
		
		
	
	
	*Table 6: Regression-Discontinuity Design: Effect of Incumbent-Aligned Newspapers on Reelection Rates.
	*+ Appendix A.9 and A.10
	
forval i = 15 (5) 25 {

	use do_newspapers_benefit_incumbents.dta, clear	
	drop if newspapers==.
	replace newspapers_aligned = 0 if newspapers_aligned==.
	replace winXnewspapers_aligned = newspapers_aligned*win
	label var newspapers "\(newspapers_{ct}\)" 
	label var winXnewspapers "\(victory_{ict} \times newspapers_{ct}\)" 
	label var newspapers_aligned "\(aligned \,\,newspapers_{ict}\)" 
	label var winXnewspapers_aligned "\(victory_{ict} \times aligned\,\, newspapers_{ict}\)" 
	label var win "\(victory_{ict}\)" 
	estimates clear
				

	estimates clear
	eststo: reg win_next winXnewspapers_aligned winXnewspapers win newspapers_aligned newspapers  	rvXwin rv    if abs(rv)< `i'  , cluster(constituency_id)  
	estadd scalar bw = `i'
		
	eststo: reg win_next winXnewspapers_aligned winXnewspapers win newspapers_aligned newspapers   	rvXwin rv  rv_2 winXrv_2    if abs(rv)<`i'  , cluster(constituency_id)  
	estadd scalar bw = `i'
	
	eststo: reghdfe win_next winXnewspapers_aligned winXnewspapers win newspapers_aligned newspapers   rvXwin rv rv_2 winXrv_2  if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id date)
	estadd scalar bw = `i'
	
	eststo: reghdfe win_next winXnewspapers_aligned winXnewspapers win newspapers_aligned newspapers   rvXwin rv rv_2 winXrv_2  if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id date constituency_id#c.date)
	estadd scalar bw = `i'		
			
	eststo: reghdfe win_next winXnewspapers_aligned winXnewspapers win newspapers_aligned newspapers   rvXwin rv rv_2 winXrv_2 electors urban_pct railroad if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id date constituency_id#c.date)
	estadd scalar bw = `i'	

	eststo: reghdfe win_next winXnewspapers_aligned winXnewspapers win newspapers_aligned newspapers   rvXwin rv rv_2 winXrv_2 electors urban_pct railroad c.electors#c.win c.urban_pct#c.win c.railroad#c.win if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id date constituency_id#c.date)
	estadd scalar bw = `i'	
	
	eststo: reghdfe win_next winXnewspapers_aligned winXnewspapers  newspapers_aligned newspapers   rvXwin rv rv_2 winXrv_2 electors urban_pct railroad  c.electors#c.win c.urban_pct#c.win c.railroad#c.win  if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id i.constituency_id#c.win date)
	estadd scalar bw = `i'
	
	esttab using "./figures_tables/rd_winXnewspapers_aligned_bw`i'.tex",  replace keep(winXnewspapers winXnewspapers_aligned win newspapers  newspapers_aligned ) label se  ///
	substitute( bw "Bandwidth" "\hline" "\midrule" ) compress  noobs nomtitles fragment scalar(N bw ) b( %4.3f)  sfmt(%9.0fc  %5.1f %4.2f) nostar 

project, creates("./figures_tables/rd_winXnewspapers_aligned_bw`i'.tex") 
		
		
}		
		
		
		

	

