

project, original("folketing_elections_1849_1915.dta")
project, uses("district_dates.dta")
project, uses("./newspapers/newspaper_info.dta")
project, uses("./mediastream/newspaper_hits.dta") 
project, uses("./railroads/railway_stations.dta")


*****************************
* Prepare data
*****************************



	
	use "folketing_elections_1849_1915.dta", clear
	drop if electiontype=="special"
	

	merge m:1  constituency date using district_dates.dta
	assert _merge==3
	drop _merge

	
	//generate indicate for whether candidate is one of the top two vote getters in a given election (i.e. constituency date)
	gsort constituency date -votes
	bys constituency date: gen toptwo = _n<=2
	
	
	//create running variable: the pct of the votes for the top two candidates
	bysort constituency date: egen totalvotes_toptwo = total(votes) if toptwo==1

	
	
	gen rv = 100*votes/totalvotes_toptwo - 50
	replace rv=. if toptwo==0
	gen rvXwin = rv*win 
	gen rv_2 = rv^2
	gen winXrv_2 = win*rv_2
	gen abs_rv = abs(rv)
	
	
	
	gen vtshmargin = 2*abs(rv)
	replace vtshmargin = 100 if uncontested==1
	bys constituency date: egen tmp = max(vtshmargin)
	replace vtshmargin = tmp
	drop tmp
	
	
	
	bysort constituency date: egen vtsh = pc(votes) , prop
	replace vtsh =100 if uncontested==1
	
	**create outcome variables
	sort constituency candidate date
	by constituency candidate: gen win_next = win[_n+1] & next_election==date[_n+1] 
	replace win_next = . if next_election==.
	by constituency candidate: gen run_next_sameconstituency = next_election==date[_n+1]	
	replace run_next_sameconstituency = . if next_election==.
	by constituency candidate: gen uncontested_next = uncontested[_n+1] & next_election==date[_n+1] 
	replace uncontested_next = . if next_election==.

	sort candidate date	
	by  candidate: gen run_next_newconstituency = constituency!=constituency[_n+1] & constituency[_n+1]!=""	
	replace run_next_newconstituency = . if next_election==.
	
	
	
	//create pre-treatment covariates
	sort constituency candidate date		
	by constituency candidate: gen win_prev= win[_n-1]==1 & prev_election==date[_n-1] 
	replace win_prev = . if prev_election==.	
	by constituency candidate: gen run_prev= prev_election==date[_n-1] 
	replace run_prev = . if prev_election==.
	by constituency candidate: gen uncontested_prev= uncontested[_n-1]==1 & prev_election==date[_n-1] 
	replace uncontested_prev = . if prev_election==.
	
	

	egen race = group(constituency date) , label
	

	
	*****************************
	* Merge in newspaper data
	*****************************		
	
	merge m:1 constituency date using ./newspapers/newspaper_info.dta 
	//_merge==1 places where newspapers cannot be mapped to a constituency, e.g. major cities like Copenhagen, Aarhus and Odense
	//_merge==2 constituency-months with no info on elections
	drop if _merge==2
	drop _merge

	
	gen paper = 0 if newspapers==0
	replace paper = 1 if newspapers>0 & newspapers!=.
	bys constituency: egen max_paper = min(year) if paper==1
	by constituency: egen first_newspaper_entry = max(max_paper)	
	
	gen newspapers_aligned = .
	replace newspapers_aligned = newspapers_højre if party=="Højre"
	replace newspapers_aligned = newspapers_venstre if party=="Venstre"
	replace newspapers_aligned = newspapers_moderate if party=="Moderate"
	replace newspapers_aligned = newspapers_socialdem if party=="Socialdemokratiet"
	replace newspapers_aligned = newspapers_radikale if party=="Radikale"
	
	gen winXnewspapers=win*newspapers
	gen winXnewspapers_aligned=win*newspapers_aligned

	
	

		

	
	tempfile tmp
	save `tmp'
	
	gen newspaper_entered = .
	replace newspaper_entered = 0 if newspapers!=.
	replace newspaper_entered = 1 if newspapers>0  & newspapers!=.
	
	contract constituency date newspaper_entered
	sort constituency date
	bys constituency: gen n = _n
	gen t = n if newspaper_entered[_n-1]==0 & newspaper_entered==1 & newspaper_entered!=.
	bys constituency: egen min_t = min(t)
	gen elections_to_entry = n - min_t
	keep constituency date elections_to_entry newspaper_entered
	
	merge 1:m constituency date using `tmp'
	drop _merge
	
	*****************************
	* Merge in newspaper hits
	*****************************		
	
	merge 1:1 constituency candidate date using ./mediastream/newspaper_hits
	drop if _merge==2
	drop _merge
	replace hits =. if candidate=="Svendborg, P Andersen" // this candidate runs in Svenborg district. Most of the hits are clearly false positives	
	replace hits_campaign_next =. if candidate=="Svendborg, P Andersen"
	replace hits_campaign_prev =. if candidate=="Svendborg, P Andersen"
	gen newscoverage = hits / (hits_rigsdag + hits_politik)
	replace newscoverage = . if (hits_rigsdag + hits_politik)<50

	*Helsingør har ikke dækning i perioden
	gen log_hits = log(hits + 1 ) 
	gen log_hits_campaign_next = log(hits_campaign_next + 1 ) 
	gen log_hits_campaign_prev = log(hits_campaign_prev + 1 ) 

	
	
	*****************************
	* Merge in railroad data
	*****************************		
	merge m:1 constituency date using ./railroads/railway_stations.dta 
	gen railroad = train_stations>0
	drop _merge
	
	
	
	gen reelection = 0 if win_next!=.
	replace reelection=1 if win==1 & win_next==1 	
	
	egen constituency_id = group(constituency) , label
	
	gen urban_pct = 100*electors_urban/electors
	
	
	save do_newspapers_benefit_incumbents.dta, replace
	             
project, creates(do_newspapers_benefit_incumbents.dta) 
	
	
	

	
	
	
