

project, uses("do_newspapers_benefit_incumbents.dta")

	*Figure 5: Diference-in-Differences Design: Effect of Newspapers on Reelection Rates.
	use do_newspapers_benefit_incumbents.dta, clear	
	drop if newspapers==.		
	keep if win==1
	sort constituency_id date
	by constituency_id: gen newspapers1 = newspapers[_n+1]
	by constituency_id: gen newspapers2 = newspapers[_n+2]	
	by constituency_id: gen newspapers3 = newspapers[_n+3]	
	by constituency_id: gen newspapers4 = newspapers[_n+4]	
	
	egen Election = group(date)
	binscatter win_next newspapers , absorb(constituency_id ) controls(i.Election ) noaddmean n(10) xtitle("Newspapers" "(Residualized)") ytitle("Reelection Rate" "(Residualized)")  line(lfit) saving("./figures_tables/partial_regression.gph", replace)  


	rename newspapers newspapers0
	reghdfe win_next newspapers4 newspapers3 newspapers2 newspapers1 newspapers0       , a(constituency_id  Election ) cluster(constituency_id)
	
	gen t = . 
	gen est = .
	gen upper90 = .
	gen upper95 = .
	gen lower90 = .
	gen lower95 = .	
	local t =0
	forval i = 0/4 {
		replace t =  -`t' if _n==`t' +1	
		replace est = _b[newspapers`i'] if _n==`t' +1
		replace upper95 = _b[newspapers`i'] + 1.96*_se[newspapers`i'] if _n==`t'+1
		replace lower95 = _b[newspapers`i'] - 1.96*_se[newspapers`i'] if _n==`t'+1
		replace upper90 = _b[newspapers`i'] + 1.64*_se[newspapers`i'] if _n==`t'+1
		replace lower90 = _b[newspapers`i'] - 1.64*_se[newspapers`i'] if _n==`t'+1
		local t = `t'+1		
	}
	
	keep if t!=.
	keep est upper* lower* t	

	twoway  (rspike upper95 lower95 t,   lwidth(vthin)   	lcolor(black) ) || ///
			(rspike upper90 lower90 t,  lwidth(medthick) 	lcolor(black) ) || ///
			(dot est t , ndots(1) msymbol(s) mfcolor(white) mcolor(black) ) || ///
			, yline(0 , lpattern(solid) lcolor(black)) ytitle("Effect of Newspapers" "on Reelection Rate") ///
			legend( off ) ///
			xtitle("Elections Relative to Newspaper Entry" " " )  saving("./figures_tables/did_est.gph", replace) ylabel(-.1 (.05) .15)
	graph combine  "./figures_tables/partial_regression"  "./figures_tables/did_est" , xsize(20) ysize(10)   iscale(1.3)
	graph export ./figures_tables/did.eps, replace	

project, creates("./figures_tables/did.eps") 
	
	
	
		
	*Table 3: Difference-in-Differences Design: Effect of Newspapers on Reelection Rates.
	use do_newspapers_benefit_incumbents.dta, clear
	estimates clear
	drop if newspapers==.
	keep if win==1
	label var newspapers "\(newspapers_{ct}\)"
	
	eststo: reghdfe reelection newspapers  , absorb(constituency_id date) cluster(constituency_id) 
	
	eststo: reghdfe reelection newspapers electors , absorb(constituency_id date) cluster(constituency_id) 

	eststo: reghdfe reelection newspapers electors urban_pct, absorb(constituency_id date) cluster(constituency_id) 
	
	eststo: reghdfe reelection newspapers electors urban_pct railroad , absorb(constituency_id date) cluster(constituency_id) 
	
	eststo: reghdfe reelection newspapers electors urban_pct railroad vtshmargin, absorb(constituency_id date) cluster(constituency_id) 
	
	eststo: reghdfe reelection newspapers electors urban_pct railroad vtshmargin, absorb(constituency_id date constituency_id#c.date) cluster(constituency_id) 
	
	esttab using "./figures_tables/did.tex",  replace keep(newspapers  ) label se  ///
	substitute( "\hline" "\midrule" ) compress  noobs nomtitles  fragment scalar(N ) b( %4.3f)  sfmt(%9.0fc ) nostar  
	
	
project, creates("./figures_tables/did.tex") 
	

	
	
	
	
	
	
	
	
	*Figure 6: Regression-Discontinuity Design: The Incumbency Advantage Is More Pronounced after the Entry of a Local Newspaper.
	use do_newspapers_benefit_incumbents.dta, clear
	gen bin = rv - mod(rv,1) +100
	drop if newspapers==.
	binscatter win_next rv if abs(rv)<15  & elections_to_entry>=0  ,xq(bin)  rd(0)  ylabel(-0 (.1) .9) xlabel(-15 (5) 15) title("After Newspaper Entry") ytitle("Victory, t+1")  xtitle("Vote Share Margin, t") saving("./figures_tables/rd_win_newspapers1.gph", replace) line(qfit)
	binscatter win_next rv if abs(rv)<15 & elections_to_entry<0 , xq(bin)   rd(0) ylabel(-0 (.1) .9) xlabel(-15 (5) 15) title("Before Newspaper Entry") ytitle("Victory, t+1")  xtitle("Vote Share Margin, t") saving("./figures_tables/rd_win_newspapers0.gph", replace) line(qfit)
	graph combine   "./figures_tables/rd_win_newspapers0"  "./figures_tables/rd_win_newspapers1" , xsize(20) ysize(10) ycommon  iscale(1.3) cols(2)
	graph export "./figures_tables/rd_newspapers.eps", replace
	
project, creates("./figures_tables/rd_newspapers.eps") 
	

	
	*Figure 7: Event Study of Newspaper Entry: The Incumbency Advantage Increases after the Entry of a Local Newspaper.
	use do_newspapers_benefit_incumbents.dta, clear
	gen est = .
	gen upper90 = .
	gen lower90 = .
	gen upper95 = .
	gen lower95 = .
	gen t = .
	qui forval i = -5/5 {
		rdrobust win_next rv if (elections_to_entry==`i' ) ,  vce(cluster race) 
		replace est = _b[RD_Estimate] if elections_to_entry==`i'
		replace upper90 = _b[RD_Estimate] + 1.64*_se[RD_Estimate] if elections_to_entry==`i'
		replace lower90 = _b[RD_Estimate] - 1.64*_se[RD_Estimate] if elections_to_entry==`i'
		replace upper95 = _b[RD_Estimate] + 1.96*_se[RD_Estimate] if elections_to_entry==`i'
		replace lower95 = _b[RD_Estimate] - 1.96*_se[RD_Estimate] if elections_to_entry==`i'
		replace t = `i' if elections_to_entry==`i'
	}


	keep if t!=.
	collapse est lower* upper*   newspapers , by(t)	
	egen pre_mean = mean(est) if t<0
	egen post_mean = mean(est) if t>=0	
	replace t =  t+.075 if t == 0
	twoway  (rspike upper95 lower95 t,   lwidth(vthin)   	lcolor(black) ) || ///
			(rspike upper90 lower90 t,  lwidth(medthick) 	lcolor(black) ) || ///
			(dot est t , ndots(1) msymbol(s) mfcolor(white) mcolor(black) ) || ///
			(line pre_mean post_mean t , lpattern(dash) )  ///
	, xline(0, lpattern(long_dash) lcolor(black) ) yline(0 ,lpattern(solid) lcolor(black)) xlabel(-5 (1) 5) ///
	ttitle("Elections relative to Newspaper Entry") ytitle("Estimated Incumbency Advantage" "(Effect of Candidate Victory at t on Victory at t+1)")	///
	legend( order ( 3 "Point Estimate" 4 "Mean Pre-Entry Effect" 5 "Mean Post-Entry Effect") ring(0) position(5) )  //1 "95% CI" 2 "90% CI"
	graph export ./figures_tables/rd_pre_post.eps, replace	
	
project, creates("./figures_tables/rd_pre_post.eps") 

	
		
	*Table 4: Regression-Discontinuity Design: Incumbency Advantage Is Stronger in the Presence of Newspapers.
	*+ Appendix Tables A.7, A.8

	forval i = 15 (5) 25 {
	
		use do_newspapers_benefit_incumbents.dta, clear	
		drop if newspapers==.
		label var newspapers "\(newspapers_{ct}\)" 
		label var winXnewspapers "\(newspapers_{ct} \times victory_{ict}\)" 
		label var win "\(vicory_{ict}\)" 
		estimates clear
				
		estimates clear
		eststo: reg win_next winXnewspapers win newspapers  	rvXwin rv    if abs(rv)<`i'  , cluster(race)  
		estadd scalar bw = `i'
			
		eststo: reg win_next winXnewspapers win newspapers  	rvXwin rv  rv_2 winXrv_2    if abs(rv)<`i'  , cluster(constituency_id)  
		estadd scalar bw = `i'
		
		eststo: reghdfe win_next winXnewspapers win newspapers  rvXwin rv rv_2 winXrv_2  if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id date)
		estadd scalar bw = `i'
		
		eststo: reghdfe win_next winXnewspapers win newspapers  rvXwin rv rv_2 winXrv_2  if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id date constituency_id#c.date)
		estadd scalar bw = `i'
		
		eststo: reghdfe win_next winXnewspapers win newspapers  rvXwin rv rv_2 winXrv_2  electors urban_pct railroad if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id date constituency_id#c.date)
		estadd scalar bw = `i'		
		
		eststo: reghdfe win_next winXnewspapers win newspapers  rvXwin rv rv_2 winXrv_2 electors urban_pct railroad c.electors#c.win c.urban_pct#c.win c.railroad#c.win   if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id date constituency_id#c.date)
		estadd scalar bw = `i'
		
		eststo: reghdfe win_next winXnewspapers  newspapers  rvXwin rv rv_2 winXrv_2 electors urban_pct railroad  c.electors#c.win c.urban_pct#c.win c.railroad#c.win  if abs(rv)<`i'  , cluster(constituency_id)  absorb(constituency_id i.constituency_id#c.win date constituency_id#c.date)
		estadd scalar bw = `i'		
				
		esttab using "./figures_tables/rd_winXnewspapers_bw`i'.tex",  replace keep(winXnewspapers win newspapers  ) label se  ///
		substitute( bw "Bandwidth" "\hline" "\midrule" ) compress  noobs nomtitles fragment scalar(N bw ) b( %4.3f)  sfmt(%5.0f  %5.1f %4.2f) nostar 
project, creates("./figures_tables/rd_winXnewspapers_bw`i'.tex") 
	
	}
			
	

	* Figure A.1
	use do_newspapers_benefit_incumbents.dta, clear	
	gen bin = rv - mod(rv,1) +100	
	binscatter win_next rv if abs(rv)<15   ,xq(bin)  rd(0)  ylabel(-0 (.1) .9) xlabel(-15 (5) 15) title("Incumbency Advantage") ytitle("Victory, t+1")  xtitle("Vote Share Margin, t")  line(qfit)
	graph export "./figures_tables/baseline_incumbency.eps", replace
	
project, creates("./figures_tables/baseline_incumbency.eps") 

	
	
	
	
	
