

project, uses("do_newspapers_benefit_incumbents.dta")



	**Descriptive Statistics
	use do_newspapers_benefit_incumbents.dta, clear	
	label var win "\( win_{i c t} \)"
	label var win_next "\( win_{ic,t+1} \)"
	label var win_prev "\( win_{ic,t-1 }\)"
	label var log_hits_campaign_next "\(log \,\,candidate \,\,mentions_{ic,t+1}\)"
	label var log_hits_campaign_prev "\(log \,\,candidate \,\,mentions_{ic t}\)"

	label var newspapers "\( newspapers_{c t }\)"
	label var newspapers_aligned "\( aligned \,\,newspapers_{ic t }\)"
	label var rv "\( running\,\, variable_{ic t} \)"
	label var railroad "\( railroad_{c t} \)"
	label var urban_pct "\( \%\,\, urban\,\, population_{c t} \)"
	label var electors "\( electors_{c t} \)"
	label var vtshmargin "\(vote \,\,share \,\,margin_{ct}\)"
	
	
	*	label var newspapers "Newspaper, t"
	
	quietly {
		cap log close
		set linesize 255
		log using "./figures_tables/DescriptiveStats.tex", text replace
		noisily dis "\begin{table}[htbp]"
		noisily dis "\begin{center}"
		noisily dis "\caption{ {\bf Summary Statistics \label{tab:stats}} }"
	*	noisily display "  }"
		noisily dis " \begin{adjustbox}{max width=0.7\textwidth} "
		noisily dis "\begin{tabular}{l ccccc}"
		noisily dis "\toprule \toprule"
		noisily dis " & Mean & St. Dev. & Min. & Max. & Obs. \\"
		noisily dis "\midrule"

		noisily dis "\\ & \multicolumn{5}{c}{Candidate-level Variables} \\"
		noisily dis " \cmidrule(lr){2-6} "		
			
		foreach var in   win win_next rv newspapers_aligned log_hits_campaign_next log_hits_campaign_prev  {
				local varlab : variable label `var'	
				qui sum `var', d
				local mean = r(mean)
				local sd = r(sd)
				local skew = r(skewness)
				local min = r(min)
				local max = r(max)
				local obs = r(N)
				noisily dis " `varlab' & " %4.2f `mean' " & "  %4.2f `sd'  " & " %4.2f `min' " & " %4.2f `max' " & " %4.0f `obs' " \\"
		}


		
		noisily dis "\\ & \multicolumn{5}{c}{Constituency-level Variables} \\"
		noisily dis " \cmidrule(lr){2-6} "		
			
		foreach var in  newspapers   electors  urban_pct railroad vtshmargin {
				local varlab : variable label `var'	
				qui sum `var', d
				local mean = r(mean)
				local sd = r(sd)
				local skew = r(skewness)
				local min = r(min)
				local max = r(max)
				local obs = r(N)
				noisily dis " `varlab' & " %4.2f `mean' " & "  %4.2f `sd'  " & " %4.2f `min' " & " %4.2f `max' " & " %4.0f `obs' " \\"
		}		
		
		
		
	
		noisily dis "\bottomrule \bottomrule"
		noisily dis "\end{tabular}"
		noisily dis "\end{adjustbox}"
		noisily dis "\end{center}"	
		noisily dis " \footnotesize{ \textsc{Note:} Each observation pertains to a candidate "
		noisily dis " in a constituency in a given election. "
		noisily dis " The reported statistics are calculated based on all parliamentary elections 1849-1915. } "
		noisily dis "\end{table}"
		
		log off
	}
	
project, creates("./figures_tables/DescriptiveStats.tex") 

